@@ -1,6 +1,6 @@
 package Hypatia::Base;
 {
-  $Hypatia::Base::VERSION = '0.021';
+  $Hypatia::Base::VERSION = '0.025';
 }
 use Moose;
 use Hypatia::DBI;
@@ -19,23 +19,26 @@ coerce "Hypatia::DBI", from "HashRef", via {Hypatia::DBI->new($_)};
 has 'dbi'=>(isa=>"Hypatia::DBI",is=>'rw',coerce=>1,predicate=>'use_dbi',handles=>['dbh']);
 
 
-subtype 'HypatiaColumns' => as class_type("Hypatia::Columns");
+subtype 'HypatiaColumns' => as maybe_type("Hypatia::Columns");
 coerce "HypatiaColumns",from "HashRef", via {Hypatia::Columns->new({columns=>$_})};
 
 #Note: the attribute here is named 'cols' so that we can use the 'columns' handle from the corresponding Hypatia::Columns object.
 #We use BUILDARGS to do the ol' switcheroo.
-has 'cols'=>(isa=>'HypatiaColumns',is=>'ro',coerce=>1,handles=>['columns']);
+has 'cols'=>(isa=>'HypatiaColumns',is=>'rw',coerce=>1,handles=>[qw(columns using_columns)],default=>sub{Hypatia::Columns->new});
 
 around BUILDARGS=>sub
 {
 	my $orig  = shift;
-    my $class = shift;
-    my $args=shift;
+	my $class = shift;
+	my $args=shift;
 	
 	confess "Argument is not a hash reference" unless ref $args eq ref {};
 	
-	$args->{cols}=$args->{columns};
-	delete $args->{columns};
+	if(exists $args->{columns})
+	{
+		$args->{cols}=$args->{columns};
+		delete $args->{columns};
+	}
 	
 	return $class->$orig($args);
 };
@@ -44,6 +47,32 @@ around BUILDARGS=>sub
 
 
 
+sub _guess_columns
+{
+	confess "The attribute 'columns' is required";
+}
+
+# This is a setup method for methods overriding _guess_columns.
+# Yes, I know about the Moose keyword 'after', but I'm not
+# sure offhand how to run the code in _setup_guess_columns
+# except if _guess_columns is being overridden.
+sub _setup_guess_columns
+{
+	my $self=shift;
+	
+	my $query=$self->dbi->_build_query;
+	
+	my $dbh=$self->dbh;
+	my $sth=$dbh->prepare($query) or die $dbh->errstr;
+	$sth->execute or die $dbh->errstr;
+	
+	my @return = @{$sth->{NAME}};
+	
+	$sth->finish;
+	
+	return \@return;
+}
+
 
 1;
 
@@ -57,7 +86,7 @@ Hypatia::Base - An Abstract Base Class
 
 =head1 VERSION
 
-version 0.021
+version 0.025
 
 =head1 ATTRIBUTES
 
@@ -94,6 +123,12 @@ to indicate a bubble chart with two sets of y values each having two different c
 
 B<Note:> The exact requirements of this attribute will vary depending on which sub-class you're calling.  Consult the relevant documentation.
 
+=head1 INTERNAL METHODS
+
+=head2 _guess_columns
+
+This can be thought of as a (quasi) abstract method. By default, this method simply invokes a L<confession|Carp>, but it's meant to be overridden by submodules.
+
 =head1 AUTHOR
 
 Jack Maney <jack@jackmaney.com>
