@@ -1,15 +1,23 @@
 package Hypatia::Columns;
 {
-  $Hypatia::Columns::VERSION = '0.021';
+  $Hypatia::Columns::VERSION = '0.025';
 }
 use Moose;
 use Array::Utils qw(unique);
 
 #Required column types, defaults to 'x' and 'y'
-has 'column_types'=>(isa=>'ArrayRef[Str]',is=>'ro',default=>sub{[qw(x y)]});
+has 'column_types'=>(isa=>'ArrayRef[Str]',is=>'rw',default=>sub{[qw(x y)]});
 
 #Actual column values...this hash ref will be filled in from the coercion
-has 'columns'=>(isa=>'HashRef[Str|ArrayRef[Str]]',is=>'ro',required=>1);
+has 'columns'=>(isa=>'HashRef[Str|ArrayRef[Str]]',is=>'rw',predicate=>'using_columns'
+	,trigger=>
+	sub{
+		my $self=shift;
+		
+		return 1 if($self->using_columns);
+		
+		return $self->_validate;
+	});
 
 #Native validation works as follows:
 #
@@ -19,7 +27,7 @@ has 'columns'=>(isa=>'HashRef[Str|ArrayRef[Str]]',is=>'ro',required=>1);
 #     then this is assumed to denote the single, common set of x-values for all values of all other columns.  1 is returned.
 # 3. If 'x' consists of an array reference of columns, then the length of this array reference must be the same as the references of all other column types.
 
-has 'use_native_validation'=>(isa=>'Bool',is=>'ro',default=>1);
+has 'use_native_validation'=>(isa=>'Bool',is=>'rw',default=>1);
 
 sub _validate
 {
@@ -78,25 +86,28 @@ sub BUILD
 	my $types=$self->column_types;
 	my $columns=$self->columns;
 	
-	my $num_types=scalar(@$types);
-	
-	unless(scalar(keys %$columns)==$num_types)
+	if($self->using_columns)
 	{
-		confess "Incorrect number of column types (should be $num_types, but I instead got " . scalar(keys %$columns) . ")";
-	}
-	
-	foreach my $col_type(keys %$columns)
-	{
-		unless(grep{$col_type eq $_}@$types)
+		my $num_types=scalar(@$types);
+		
+		unless(scalar(keys %$columns)==$num_types)
 		{
-			confess "Column type '$col_type' not found in the column_types attribute (containing " . join(",",map{"'" . $_ . "'"}@$types) . ")";
+			confess "Incorrect number of column types (should be $num_types, but I instead got " . scalar(keys %$columns) . ")";
 		}
 		
-	}
-	
-	if($self->use_native_validation)
-	{
-		confess "Validation failed" unless $self->_validate;
+		foreach my $col_type(keys %$columns)
+		{
+			unless(grep{$col_type eq $_}@$types)
+			{
+				confess "Column type '$col_type' not found in the column_types attribute (containing " . join(",",map{"'" . $_ . "'"}@$types) . ")";
+			}
+			
+		}
+		
+		if($self->use_native_validation)
+		{
+			confess "Validation failed" unless $self->_validate;
+		}
 	}
 }
 
@@ -114,7 +125,7 @@ Hypatia::Columns
 
 =head1 VERSION
 
-version 0.021
+version 0.025
 
 =head1 AUTHOR
 
